/*
 *******************************************************************************
 *
 *  Copyright 2024 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
#define RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1

// Meta data item definition version
const char* const RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const char* const RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
typedef struct MetaDataItemInfo
{
    const char*   name;
    const char*   title;
    const char*   description;
    unsigned char status;
    const char*   schema;
    const char*   example;
} MetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"angle\":{\"type\":\"array\",\"description\":\"Angle [deg]\",\"it"
    "ems\":{\"type\":\"number\"}},\"range_mean\":{\"type\":\"array\",\"description\":\"Me"
    "an range [m]\",\"items\":{\"type\":\"number\"}},\"amplitude_mean\":{\"type\":\"arr"
    "ay\",\"description\":\"Mean amplitude [dB]\",\"items\":{\"type\":\"number\"}}},\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"des"
    "cription\":\"Angular notch filter parameters for window glass echoes\",\"r"
    "equired\":[\"angle\",\"range_mean\",\"amplitude_mean\"],\"title\":\"Angular "
    "Notch Filter\"}"
    ,
    /* example: */
    "{\"angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],\"ran"
    "ge_mean\":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,"
    "0.0675,0.06475],\"amplitude_mean\":[3.780913,3.780913,3.480913,3.120913,"
    "2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"temperature\":{\"type\":\"number\",\"description\":\"Temperatu"
    "re along measurement path "
    "[\\u00b0C]\"},\"pressure\":{\"type\":\"number\",\"description\":\"Pressure along "
    "measurment path "
    "[mbar]\"},\"pressure_sl\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "pressure at sea level "
    "[mbar]\"},\"attenuation\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\"},\"wavelength\":{\"type\":\"number\",\"description\":\"Laser wavelength"
    " [nm]\"},\"rel_humidity\":{\"type\":\"number\",\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\"},\"amsl\":{\"type\":\"number\",\"description\":\"Height above mean sea "
    "level (AMSL) "
    "[m]\"},\"group_velocity\":{\"type\":\"number\",\"description\":\"Group velocity "
    "of laser beam [m/s]\"}},\"$schema\":\"http://json-schema.org/draft-04/sche"
    "ma#\",\"type\":\"object\",\"description\":\"Atmospheric parameters\",\"required\""
    ":[\"temperature\",\"pressure\",\"rel_humidity\",\"pressure_sl\",\"amsl\",\"group_"
    "velocity\",\"attenuation\",\"wavelength\"],\"title\":\"Atmospheric "
    "Parameters\"}"
    ,
    /* example: */
    "{\"temperature\":7,\"pressure\":970,\"pressure_sl\":970,\"attenuation\":0.0281"
    "25,\"wavelength\":1550,\"rel_humidity\":63,\"amsl\":0,\"group_velocity\":29971"
    "1000.0}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"beam_exit_diameter\":{\"type\":\"number\",\"description\":\"Be"
    "am width at exit aperture [m]\",\"exclusiveMinimum\":false,\"minimum\":0},\""
    "beam_divergence\":{\"type\":\"number\",\"description\":\"Beam divergence in "
    "far field [rad]\",\"exclusiveMinimum\":false,\"minimum\":0}},\"$schema\":\"htt"
    "p://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"description\":\"L"
    "aser beam geometry details\",\"required\":[\"beam_exit_diameter\",\"beam_div"
    "ergence\"],\"title\":\"Beam Geometry\"}"
    ,
    /* example: */
    "{\"beam_exit_diameter\":0.0072,\"beam_divergence\":0.0003}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"round_corner_cube_prism\":{\"type\":\"object\",\"descriptio"
    "n\":\"round corner cube prism\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},"
    "{\"type\":\"object\",\"description\":\"round corner cube prism specific prope"
    "rties\",\"properties\":{\"offset\":{\"type\":\"number\",\"description\":\"offset "
    "in meters, e.g. reflector constant (optional)\"},\"shape\":{\"type\":\"strin"
    "g\",\"enum\":[\"round_corner_cube_prism\"],\"description\":\"shape "
    "identifier\"},\"diameter\":{\"type\":\"number\",\"description\":\"diameter in me"
    "ters\",\"exclusiveMinimum\":true,\"minimum\":0}},\"required\":[\"shape\",\"diame"
    "ter\"]}]},\"chevron\":{\"type\":\"object\",\"description\":\"chevron\",\"allOf\":[{"
    "\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"description\":\"chevron"
    " specific properties\",\"properties\":{\"thickness\":{\"type\":\"number\",\"desc"
    "ription\":\"thickness in meters\",\"exclusiveMinimum\":true,\"minimum\":0},\"s"
    "hape\":{\"type\":\"string\",\"enum\":[\"chevron\"],\"description\":\"shape identif"
    "ier\"},\"outside_edge_length\":{\"type\":\"number\",\"description\":\"length of "
    "the two outer edges in meters\",\"exclusiveMinimum\":true,\"minimum\":0}},\""
    "required\":[\"shape\",\"outside_edge_length\",\"thickness\"]}]},\"cylinder\":{\""
    "type\":\"object\",\"description\":\"cylinder\",\"allOf\":[{\"$ref\":\"#/definition"
    "s/common\"},{\"type\":\"object\",\"description\":\"cylinder specific propertie"
    "s\",\"properties\":{\"height\":{\"type\":\"number\",\"description\":\"height in me"
    "ters\",\"exclusiveMinimum\":true,\"minimum\":0},\"shape\":{\"type\":\"string\",\"e"
    "num\":[\"cylinder\"],\"description\":\"shape "
    "identifier\"},\"diameter\":{\"type\":\"number\",\"description\":\"diameter in me"
    "ters\",\"exclusiveMinimum\":true,\"minimum\":0}},\"required\":[\"shape\",\"diame"
    "ter\",\"height\"]}]},\"rectangle\":{\"type\":\"object\",\"description\":\"rectangl"
    "e\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"descript"
    "ion\":\"rectangle specific properties\",\"properties\":{\"width\":{\"type\":\"nu"
    "mber\",\"description\":\"width in meters\",\"exclusiveMinimum\":true,\"minimum"
    "\":0},\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle\"]},\"length\":{\"type\":\""
    "number\",\"description\":\"length in meters\",\"exclusiveMinimum\":true,\"mini"
    "mum\":0}},\"required\":[\"shape\",\"length\",\"width\"]}]},\"checkerboard2x2\":{\""
    "type\":\"object\",\"description\":\"checkerboard 2 by 2\",\"allOf\":[{\"$ref\":\"#"
    "/definitions/common\"},{\"type\":\"object\",\"description\":\"checkerboard "
    "specific properties\",\"properties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"c"
    "heckerboard2x2\"],\"description\":\"shape "
    "identifier\"},\"square_length\":{\"type\":\"number\",\"description\":\"length of"
    " a square of the checkerboard in meters\",\"exclusiveMinimum\":true,\"mini"
    "mum\":0}},\"required\":[\"shape\",\"square_length\"]}]},\"circular_disk\":{\"typ"
    "e\":\"object\",\"description\":\"circular disk\",\"allOf\":[{\"$ref\":\"#/definiti"
    "ons/common\"},{\"type\":\"object\",\"description\":\"circular disk specific pr"
    "operties\",\"properties\":{\"offset\":{\"type\":\"number\",\"description\":\"offse"
    "t in meters, e.g. reflector constant (optional)\"},\"shape\":{\"type\":\"str"
    "ing\",\"enum\":[\"circular_disk\"],\"description\":\"shape "
    "identifier\"},\"diameter\":{\"type\":\"number\",\"description\":\"diameter in me"
    "ters\",\"exclusiveMinimum\":true,\"minimum\":0}},\"required\":[\"shape\",\"diame"
    "ter\"]}]},\"common\":{\"type\":\"object\",\"description\":\"common object proper"
    "ties\",\"properties\":{\"description\":{\"type\":\"string\",\"description\":\"stri"
    "ng describing the "
    "object\"},\"name\":{\"type\":\"string\",\"description\":\"unique type identifier"
    "\",\"minLength\":3},\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle\",\"checker"
    "board2x2\",\"chevron\",\"circular_disk\",\"cylinder\",\"sphere\",\"round_corner_"
    "cube_prism\"],\"description\":\"shape identifier\"},\"surface_type\":{\"type\":"
    "\"string\",\"enum\":[\"retro_reflective_foil\",\"diffuse\"],\"description\":\"sur"
    "face material type\"}},\"required\":[\"name\",\"shape\"]},\"sphere\":{\"type\":\"o"
    "bject\",\"description\":\"sphere\",\"allOf\":[{\"$ref\":\"#/definitions/common\"}"
    ",{\"type\":\"object\",\"description\":\"sphere specific properties\",\"properti"
    "es\":{\"shape\":{\"type\":\"string\",\"enum\":[\"sphere\"],\"description\":\"shape "
    "identifier\"},\"diameter\":{\"type\":\"number\",\"description\":\"diameter in me"
    "ters\",\"exclusiveMinimum\":true,\"minimum\":0}},\"required\":[\"shape\",\"diame"
    "ter\"]}]}},\"properties\":{\"types\":{\"type\":\"array\",\"items\":{\"type\":\"objec"
    "t\",\"oneOf\":[{\"$ref\":\"#/definitions/rectangle\"},{\"$ref\":\"#/definitions/"
    "checkerboard2x2\"},{\"$ref\":\"#/definitions/chevron\"},{\"$ref\":\"#/definiti"
    "ons/circular_disk\"},{\"$ref\":\"#/definitions/cylinder\"},{\"$ref\":\"#/defin"
    "itions/sphere\"},{\"$ref\":\"#/definitions/round_corner_cube_prism\"}]},\"un"
    "iqueItems\":true}},\"$schema\":\"http://json-schema.org/draft-04/schema#\","
    "\"type\":\"object\",\"description\":\"List of control object type "
    "definitions\",\"required\":[\"types\"],\"title\":\"Control Object Catalog\"}"
    ,
    /* example: */
    "{\"comments\":[\"This file contains a list of control object types (aka. "
    "'catalog').\",\"Each type is described by an object,\",\"which must "
    "contain at least the following parameters:\",\"  - name: unique "
    "identifier of the type\",\"  - shape: one of the following supported "
    "shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\"      - "
    "chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - sphere\",\""
    "      - round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or "
    "'diffuse')\"],\"types\":[{\"width\":0.3,\"description\":\"Rectangle (60cm x "
    "30cm)\",\"name\":\"Rectangle 60x30\",\"shape\":\"rectangle\",\"length\":0.6},{\"wi"
    "dth\":0.4,\"description\":\"Rectangle (80cm x 40cm)\",\"name\":\"Rectangle 80x"
    "40\",\"shape\":\"rectangle\",\"length\":0.8},{\"square_length\":0.3,\"descriptio"
    "n\":\"Checkerboard (square length: 30cm)\",\"name\":\"Checkerboard2x2 30\",\"s"
    "hape\":\"checkerboard2x2\"},{\"square_length\":0.5,\"description\":\"Checkerbo"
    "ard (square length: 50cm)\",\"name\":\"Checkerboard2x2 50\",\"shape\":\"checke"
    "rboard2x2\"},{\"outside_edge_length\":0.6096,\"description\":\"Chevron "
    "(a=24''; b=4'')\",\"name\":\"Chevron 24''/4''\",\"shape\":\"chevron\",\"thicknes"
    "s\":0.1016},{\"surface_type\":\"diffuse\",\"description\":\" Circular Disk "
    "(diameter: 50cm)\",\"name\":\"Circular Disk 50\",\"shape\":\"circular_disk\",\"d"
    "iameter\":0.5},{\"offset\":0.0,\"name\":\"RIEGL flat reflector 50 "
    "mm\",\"shape\":\"circular_disk\",\"diameter\":0.05,\"description\":\"flat "
    "circular reflector from retro-reflective foil\",\"surface_type\":\"retro_r"
    "eflective_foil\"},{\"offset\":0.0,\"name\":\"RIEGL flat reflector 100 "
    "mm\",\"shape\":\"circular_disk\",\"diameter\":0.1,\"description\":\"flat "
    "circular reflector from retro-reflective foil\",\"surface_type\":\"retro_r"
    "eflective_foil\"},{\"offset\":0.0,\"name\":\"RIEGL flat reflector 150 "
    "mm\",\"shape\":\"circular_disk\",\"diameter\":0.15,\"description\":\"flat "
    "circular reflector from retro-reflective foil\",\"surface_type\":\"retro_r"
    "eflective_foil\"},{\"height\":0.05,\"name\":\"RIEGL cylindrical reflector 50"
    " mm\",\"shape\":\"cylinder\",\"diameter\":0.05,\"description\":\"cylindrical "
    "reflector from retro-reflective foil\",\"surface_type\":\"retro_reflective"
    "_foil\"},{\"height\":0.1,\"name\":\"RIEGL cylindrical reflector 100 "
    "mm\",\"shape\":\"cylinder\",\"diameter\":0.1,\"description\":\"cylindrical "
    "reflector from retro-reflective "
    "foil\",\"surface_type\":\"retro_reflective_foil\"},{\"description\":\"Sphere "
    "(diameter: 200 mm)\",\"name\":\"Sphere 200 mm\",\"shape\":\"sphere\",\"diameter\""
    ":0.2},{\"offset\":0.0,\"description\":\"round corner cube "
    "prism\",\"name\":\"Corner Cube Prism 50 "
    "mm\",\"shape\":\"round_corner_cube_prism\",\"diameter\":0.05}]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about the control object "
    "reference file\",\"properties\":{\"reference_file\":{\"type\":\"object\",\"descr"
    "iption\":\"Reference to a control object file\",\"properties\":{\"file_uuid\""
    ":{\"type\":\"string\",\"description\":\"Control object file's Universally "
    "Unique Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the "
    "control object file relative to referring file\"}},\"required\":[\"file_uu"
    "id\",\"file_path\"]}},\"$schema\":\"http://json-schema.org/draft-04/schema#\""
    ",\"title\":\"Control Object Reference file\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\","
    "\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoints.cpx\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"detection_probability\":{\"type\":\"array\",\"description\":\""
    "Detection probability [0..1]\",\"items\":{\"type\":\"number\"}},\"amplitude\":{"
    "\"type\":\"array\",\"description\":\"Amplitude [dB]\",\"items\":{\"type\":\"number\""
    "}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object"
    "\",\"description\":\"Detection probability as a function of amplitude\",\"re"
    "quired\":[\"amplitude\",\"detection_probability\"],\"title\":\"Detection "
    "Probability\"}"
    ,
    /* example: */
    "{\"detection_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]"
    ",\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device "
    "build variant\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device "
    "type identifier (e.g. "
    "VZ-400i)\"},\"channel_number\":{\"type\":\"integer\",\"description\":\"Laser "
    "channel number (not defined or 0: single channel device)\",\"exclusiveMi"
    "nimum\":false,\"minimum\":0}},\"$schema\":\"http://json-schema.org/draft-04/"
    "schema#\",\"type\":\"object\",\"description\":\"Details about the device used "
    "to acquire the point "
    "cloud\",\"required\":[\"device_type\",\"serial_number\"],\"title\":\"Device "
    "Information\"}"
    ,
    /* example: */
    "{\"device_name\":\"Scanner 1\",\"channel_text\":\"\",\"serial_number\":\"S2221234"
    "\",\"device_build\":\"\",\"device_type\":\"VZ-400i\",\"channel_number\":0}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"secondary\":{\"type\":\"object\",\"description\":\"Additional "
    "device geometry structure (optional)\",\"properties\":{\"ID\":{\"type\":\"arra"
    "y\",\"description\":\"Structure identifier\",\"items\":{\"type\":\"integer\"},\"ma"
    "xItems\":2,\"minItems\":2},\"content\":{\"type\":\"array\",\"description\":\"Inter"
    "nal calibration values\",\"items\":{\"type\":\"number\"}}},\"required\":[\"ID\",\""
    "content\"]},\"amu\":{\"type\":\"object\",\"description\":\"Angle Measurement "
    "Unit\",\"properties\":{\"frameCC\":{\"type\":\"number\",\"description\":\"Frame "
    "Circle Count (number of LSBs per full rotation about frame axis)\",\"exc"
    "lusiveMinimum\":false,\"minimum\":0},\"lineCC\":{\"type\":\"number\",\"descripti"
    "on\":\"Line Circle Count (number of LSBs per full rotation about line ax"
    "is)\",\"exclusiveMinimum\":false,\"minimum\":0}}},\"primary\":{\"type\":\"object"
    "\",\"description\":\"Primary device geometry structure (mandatory)\",\"prope"
    "rties\":{\"ID\":{\"type\":\"array\",\"description\":\"Structure identifier\",\"ite"
    "ms\":{\"type\":\"integer\"},\"maxItems\":2,\"minItems\":2},\"content\":{\"type\":\"a"
    "rray\",\"description\":\"Internal calibration values\",\"items\":{\"type\":\"num"
    "ber\"}}},\"required\":[\"ID\",\"content\"]}},\"$schema\":\"http://json-schema.or"
    "g/draft-04/schema#\",\"type\":\"object\",\"description\":\"Scanner device "
    "geometry details\",\"required\":[\"primary\"],\"title\":\"Device Geometry\"}"
    ,
    /* example: */
    "{\"secondary\":{\"ID\":[91,0],\"content\":[0]},\"amu\":{\"frameCC\":124000,\"line"
    "CC\":124000},\"primary\":{\"ID\":[4,0],\"content\":[0]}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"primary\":{\"type\":\"object\",\"description\":\"Primary "
    "device geometry structure (mandatory)\",\"properties\":{\"ID\":{\"type\":\"arr"
    "ay\",\"description\":\"Structure identifier\",\"items\":{\"type\":\"integer\"},\"m"
    "axItems\":2,\"minItems\":2},\"content\":{\"type\":\"array\",\"description\":\"Inte"
    "rnal calibration values\",\"items\":{\"type\":\"number\"}}},\"required\":[\"ID\","
    "\"content\"]}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type"
    "\":\"object\",\"description\":\"Scanner passive channel device geometry "
    "details\",\"required\":[\"primary\"],\"title\":\"Device Geometry Passive "
    "Channel\"}"
    ,
    /* example: */
    "{\"primary\":{\"ID\":[143,0],\"content\":[0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Limits of the measured values output "
    "by the device. The limits depend on the device type, measurement "
    "program and/or scan pattern.\",\"properties\":{\"deviation_maximum\":{\"type"
    "\":\"number\",\"description\":\"Maximum possible pulse shape "
    "deviation.\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible range in meters.\"},\"mta_zone_count_maximum\":{\"type\":\"number\","
    "\"description\":\"Maximum number of MTA "
    "zones.\"},\"amplitude_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible amplitude in dB.\"},\"background_radiation_minimum\":{\"type\":\"nu"
    "mber\",\"description\":\"Minimum possible background radiation.\"},\"backgro"
    "und_radiation_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible background radiation.\"},\"reflectance_maximum\":{\"type\":\"number"
    "\",\"description\":\"Maximum possible reflectance in "
    "dB.\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum possible"
    " range in meters.\"},\"reflectance_minimum\":{\"type\":\"number\",\"descriptio"
    "n\":\"Minimum possible reflectance in "
    "dB.\"},\"deviation_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible pulse shape deviation.\"},\"amplitude_minimum\":{\"type\":\"number\""
    ",\"description\":\"Minimum possible amplitude in "
    "dB.\"},\"echo_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "number of echoes a laser shot can have.\"}},\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"title\":\"Device Output Limits\"}"
    ,
    /* example: */
    "{\"deviation_maximum\":32767,\"reflectance_maximum\":100.0,\"range_maximum\""
    ":10000.0,\"mta_zone_count_maximum\":7,\"reflectance_minimum\":-100.0,\"ampl"
    "itude_maximum\":100.0,\"background_radiation_minimum\":0,\"range_minimum\":"
    "2.9,\"deviation_minimum\":-1,\"amplitude_minimum\":0.0,\"background_radiati"
    "on_maximum\":0}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"items\":{\"type\":\"object\",\"properties\":{\"device_name\":{"
    "\"type\":\"string\",\"description\":\"Optional device name (e.g. 'Scanner 1' "
    "for multi-scanner "
    "systems)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"signed\":{\"type\":\"boolean\",\"description\":\"Flag that is set"
    " when the original 'riegl.device' entry in the source file was "
    "correctly "
    "signed.\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build "
    "variant\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"channel_number\":{\"type\":\"integer\",\"description\":\"Laser "
    "channel number (not defined or 0: single channel device)\",\"exclusiveMi"
    "nimum\":false,\"minimum\":0}},\"required\":[\"device_type\",\"serial_number\"]}"
    ",\"description\":\"Details about the devices used to acquire the point "
    "cloud (e.g. when merging point clouds of different devices)\",\"$schema\""
    ":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Devices "
    "Information\"}"
    ,
    /* example: */
    "[{\"device_name\":\"Scanner 1\",\"channel_text\":\"\",\"serial_number\":\"S222123"
    "4\",\"signed\":false,\"device_build\":\"\",\"device_type\":\"VZ-400i\",\"channel_n"
    "umber\":0},{\"device_name\":\"Scanner 2\",\"channel_text\":\"\",\"serial_number\""
    ":\"S2222680\",\"signed\":true,\"device_build\":\"\",\"device_type\":\"VQ-1560i-DW"
    "\",\"channel_number\":1},{\"device_name\":\"Scanner 3\",\"channel_text\":\"\",\"se"
    "rial_number\":\"S2222680\",\"signed\":true,\"device_build\":\"\",\"device_type\":"
    "\"VQ-1560i-DW\",\"channel_number\":2}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Dyntrig\",\"properties\":{\"offset\":{\"type\":\"number\",\"desc"
    "ription\":\"Offset in units of dB, for calculation of "
    "line\"},\"scale\":{\"type\":\"number\",\"description\":\"Scale in units of dB, "
    "for calculation of line: line number N=(amplitude-offset)/scale\"},\"tab"
    "\":{\"type\":\"array\",\"items\":{\"type\":\"object\",\"description\":\"...\",\"proper"
    "ties\":{\"del2\":{\"type\":\"number\",\"description\":\"Length of constant "
    "pre-trigger threshold elevation in units of "
    "m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold in "
    "units of dB\"},\"del1\":{\"type\":\"number\",\"description\":\"Length of "
    "constant post-trigger threshold elevation in units of "
    "m\"},\"dec1\":{\"type\":\"number\",\"description\":\"Decay of post-trigger "
    "threshold after del1 in units of "
    "dB/m\"},\"dec2\":{\"type\":\"number\",\"description\":\"Rise of pre-trigger "
    "threshold after del2 in units of "
    "dB/m\"},\"thra2\":{\"type\":\"number\",\"description\":\"Pre-trigger threshold "
    "in units of dB\"}},\"required\":[\"thra1\",\"del1\",\"dec1\",\"thra2\",\"del2\",\"de"
    "c2\"]},\"minItems\":1,\"maxItems\":128,\"description\":\"...\"},\"post\":{\"type\":"
    "\"object\",\"description\":\"Dyntrig post "
    "values\",\"properties\":{\"nc\":{\"type\":\"integer\",\"description\":\"Number of "
    "entries\",\"maximum\":255,\"minimum\":0},\"a\":{\"type\":\"array\",\"items\":{\"type"
    "\":\"number\"},\"minItems\":1,\"maxItems\":2080,\"description\":\"...\"}},\"requir"
    "ed\":[\"nc\",\"a\"]},\"pre\":{\"type\":\"object\",\"description\":\"Dyntrig pre "
    "values\",\"properties\":{\"nc\":{\"type\":\"integer\",\"description\":\"Number of "
    "entries\",\"maximum\":255,\"minimum\":0},\"a\":{\"type\":\"array\",\"items\":{\"type"
    "\":\"number\"},\"minItems\":1,\"maxItems\":2080,\"description\":\"...\"}},\"requir"
    "ed\":[\"nc\",\"a\"]}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\""
    "title\":\"Dyntrig\"}"
    ,
    /* example: */
    "{\"offset\":0.0,\"scale\":1.0,\"tab\":[{\"del2\":0.0,\"thra1\":0.0,\"del1\":0.0,\"d"
    "ec1\":0.0,\"dec2\":0.0,\"thra2\":0.0}],\"post\":{\"nc\":128,\"a\":[78,86,126,134,"
    "31]},\"pre\":{\"nc\":128,\"a\":[78,86,126,134,31]}}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"echo_file\":{\"type\":\"object\",\"properties\":{\"file_uuid\":"
    "{\"type\":\"string\",\"description\":\"File's Universally Unique Identifier "
    "(RFC 4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Echo "
    "file extension, without the leading dot\"}},\"required\":[\"file_extension"
    "\"]}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"objec"
    "t\",\"description\":\"Details about echo "
    "files\",\"required\":[\"echo_file\"],\"title\":\"Echo Information\"}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_uuid\":\"26a03615-67c0-4bea-8fe8-c577378fe661\",\"file"
    "_extension\":\"owp\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"channel\":{\"type\":\"object\",\"properties\":{\"scale\":{\"typ"
    "e\":\"number\",\"description\":\"amplitude "
    "calibration\"},\"delay\":{\"type\":\"number\",\"description\":\"delay "
    "calibration in seconds\"},\"a_lin\":{\"exclusiveMinimum\":false,\"type\":\"num"
    "ber\",\"exclusiveMaximum\":false,\"description\":\"relative linear amplitude"
    " range [0..1]\",\"maximum\":1,\"minimum\":0},\"parameter\":{\"type\":\"object\",\""
    "description\":\"parameters of the syswave exponential "
    "sum\",\"properties\":{\"omega\":{\"type\":\"array\",\"description\":\"angular "
    "frequency in Hz\",\"items\":{\"type\":\"number\"}},\"B\":{\"type\":\"array\",\"descr"
    "iption\":\"imaginary part of amplitude factor in units of full-scale\",\"i"
    "tems\":{\"type\":\"number\"}},\"gamma\":{\"type\":\"array\",\"description\":\"decay "
    "in 1/second\",\"items\":{\"type\":\"number\"}},\"A\":{\"type\":\"array\",\"descripti"
    "on\":\"real part of amplitude factor in units of full-scale\",\"items\":{\"t"
    "ype\":\"number\"}}},\"required\":[\"A\",\"B\",\"gamma\",\"omega\"]}},\"required\":[\"d"
    "elay\",\"scale\",\"parameter\"]}},\"additionalProperties\":false,\"$schema\":\"h"
    "ttp://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"description\":"
    "\"Details for exponential decomposition of full waveform data\",\"pattern"
    "Properties\":{\"^[0-9]+$\":{\"$ref\":\"#/definitions/channel\",\"description\":"
    "\"one field per channel, field name is channel "
    "index\"}},\"title\":\"Exponential Decomposition\"}"
    ,
    /* example: */
    "{\"1\":{\"scale\":1.0,\"delay\":3.5e-09,\"a_lin\":0.9,\"parameter\":{\"omega\":[35"
    "2020896.0,3647927552.0,-1977987072.0],\"B\":[-3.9,0.0,-0.3],\"gamma\":[-10"
    "94726528.0,-769562752.0,-848000064.0],\"A\":[0.9,0.3,-1.3]}},\"0\":{\"scale"
    "\":1.0,\"delay\":3.783458418887631e-09,\"a_lin\":0.27,\"parameter\":{\"omega\":"
    "[352020896.0,3647927552.0,-1977987072.0],\"B\":[-3.9813032150268555,0.08"
    "622030913829803,-0.3152860999107361],\"gamma\":[-1094726528.0,-769562752"
    ".0,-848000064.0],\"A\":[0.9772450923919678,0.3354335129261017,-1.3126785"
    "75515747]}}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"range_offset_sec_high_power\":{\"type\":\"array\",\"items\":{"
    "\"type\":\"number\"}},\"amplitude_db\":{\"type\":\"array\",\"items\":{\"type\":\"numb"
    "er\"}},\"range_offset_sec_low_power\":{\"type\":\"array\",\"items\":{\"type\":\"nu"
    "mber\"}},\"amplitude_lsb_low_power\":{\"type\":\"array\",\"items\":{\"type\":\"num"
    "ber\"}},\"amplitude_lsb_high_power\":{\"type\":\"array\",\"items\":{\"type\":\"num"
    "ber\"}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"ob"
    "ject\",\"description\":\"riegl.gaussian_decomposition contains information"
    " relevant for extracting calibrated amplitudes and calibrated ranges "
    "from a Gaussian decomposition of full waveform data. This information "
    "is contained in a table with five columns. Two columns are to be used "
    "as input: amplitude_lsb_low_power and amplitude_lsb_high_power. The "
    "other three columns provide the outputs. Amplitude_db gives the "
    "calibrated amplitude in the optical regime in decibels. The range "
    "offset columns provide additive range offsets, given in units of "
    "seconds, for each channel.\",\"required\":[\"amplitude_lsb_low_power\",\"amp"
    "litude_lsb_high_power\",\"amplitude_db\",\"range_offset_sec_low_power\",\"ra"
    "nge_offset_sec_high_power\"],\"title\":\"Gaussian Decomposition\"}"
    ,
    /* example: */
    "{\"range_offset_sec_high_power\":[],\"amplitude_db\":[],\"range_offset_sec_"
    "low_power\":[],\"amplitude_lsb_low_power\":[],\"amplitude_lsb_high_power\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Point cloud georeferencing information"
    "\",\"properties\":{\"pose\":{\"type\":\"array\",\"description\":\"Coordinate "
    "Transformation Matrix to transform from File Coordinate System to "
    "Global Coordinate Reference System. 4x4 matrix stored as two "
    "dimensional array, row major order.\",\"items\":{\"type\":\"array\",\"descript"
    "ion\":\"rows\",\"items\":{\"type\":\"number\",\"description\":\"columns\"},\"maxItem"
    "s\":4,\"minItems\":4},\"maxItems\":4,\"minItems\":4},\"crs\":{\"type\":\"object\",\""
    "description\":\"Global Coordinate Reference System. Please note that "
    "only 3D Cartesian Coordinate Systems are allowed.\",\"properties\":{\"name"
    "\":{\"type\":\"string\",\"description\":\"Coordinate reference system "
    "name\"},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\"},\"epsg\":{\"type\":\"integer\",\"description\":\"EPSG code\",\"minimum\""
    ":0}}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Ge"
    "o Tag\"}"
    ,
    /* example: */
    "{\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,4063"
    "882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847,113"
    "8787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196],[0"
    ".0,0.0,0.0,1.0]],\"crs\":{\"name\":\"WGS84 "
    "Geocentric\",\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS84\\\",SPHEROI"
    "D[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AU"
    "THORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AU"
    "THORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.00000000000000000000,AUTH"
    "ORITY[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAST],AXIS[\\\"Z\\"
    "\",NORTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"epsg\":4978}}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"number\",\"description\":\"Geometric scale factor applied to "
    "point coordinates\",\"exclusiveMinimum\":true,\"minimum\":0,\"$schema\":\"http"
    "://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Parameters used for georeferencing of "
    "the point cloud\",\"properties\":{\"socs_to_body_matrix\":{\"type\":\"array\",\""
    "description\":\"Coordinate Transformation Matrix to transform from "
    "Scanner's Own Coordinate System to Body Coordinate System. 4x4 matrix "
    "stored as two dimensional array, row major order.\",\"items\":{\"type\":\"ar"
    "ray\",\"description\":\"rows\",\"items\":{\"type\":\"number\",\"description\":\"colu"
    "mns\"},\"maxItems\":4,\"minItems\":4},\"maxItems\":4,\"minItems\":4},\"socs_to_r"
    "ocs_matrix\":{\"type\":\"array\",\"description\":\"Coordinate Transformation "
    "Matrix to transform from Scanner's Own Coordinate System to Record "
    "Coordinate System. 4x4 matrix stored as two dimensional array, row "
    "major order.\",\"items\":{\"type\":\"array\",\"description\":\"rows\",\"items\":{\"t"
    "ype\":\"number\",\"description\":\"columns\"},\"maxItems\":4,\"minItems\":4},\"max"
    "Items\":4,\"minItems\":4},\"body_coordinate_system_type\":{\"type\":\"string\","
    "\"enum\":[\"NED\",\"ENU\"],\"description\":\"BODY coordinate frame (NED: "
    "North-East-Down, ENU: East-North-Up), default: "
    "NED\"},\"trajectory_file\":{\"type\":\"object\",\"description\":\"Trajectory "
    "data used for georeferencing of the point cloud\",\"properties\":{\"file_u"
    "uid\":{\"type\":\"string\",\"description\":\"File's Universally Unique "
    "Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Trajectory "
    "file extension, without the leading dot\"}},\"required\":[\"file_extension"
    "\"]},\"trajectory_offsets\":{\"type\":\"object\",\"description\":\"Correction "
    "offsets applied to the trajectory data\",\"properties\":{\"offset_north\":{"
    "\"type\":\"number\",\"description\":\"[m]\"},\"offset_height\":{\"type\":\"number\","
    "\"description\":\"[m]\"},\"offset_east\":{\"type\":\"number\",\"description\":\"[m]"
    "\"},\"version\":{\"type\":\"integer\",\"description\":\"Meaning of offset values"
    " and how to apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\"},\"offset_roll\":{\"type\":\"number\",\"description\":\"[deg"
    "]\"},\"offset_yaw\":{\"type\":\"number\",\"description\":\"[deg]\"},\"offset_time\""
    ":{\"type\":\"number\",\"description\":\"[s]\"},\"offset_pitch\":{\"type\":\"number\""
    ",\"description\":\"[deg]\"}}}},\"$schema\":\"http://json-schema.org/draft-04/"
    "schema#\",\"title\":\"Georeferencing Parameters\"}"
    ,
    /* example: */
    "{\"socs_to_body_matrix\":[[-0.269827776749716,-0.723017716139738,0.63595"
    "4678449952,0.0],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",0.0],[0.0,0.660451759194338,0.7508684796801,0.0],[0.0,0.0,0.0,1.0]],\""
    "body_coordinate_system_type\":\"NED\",\"trajectory_file\":{\"file_uuid\":\"93a"
    "03615-66c0-4bea-8ff8-c577378fe660\",\"file_extension\":\"pofx\"},\"trajector"
    "y_offsets\":{\"offset_north\":0.07,\"offset_height\":-0.2,\"offset_east\":0.1"
    "5,\"version\":0,\"offset_roll\":0.03,\"offset_yaw\":-0.45,\"offset_time\":18.0"
    "07,\"offset_pitch\":0.01}}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"additionalProperties\":false,\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"type\":\"object\",\"description\":\"Map of item names\",\"pattern"
    "Properties\":{\"^-?[0-9]+$\":{\"type\":\"string\",\"description\":\"One field "
    "per item, field name is item id, field value is item "
    "name\"}},\"title\":\"Item Names\"}"
    ,
    /* example: */
    "{\"47\":\"Name of item with id 47\",\"-1\":\"Name of item with id "
    "-1\",\"1\":\"Name of item with id 1\",\"2\":\"Name of item with id 2\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"additionalProperties\":false,\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"type\":\"object\",\"description\":\"License keys for software f"
    "eatures\",\"patternProperties\":{\"^.*$\":{\"type\":\"array\",\"description\":\"Ea"
    "ch field of the object represents a feature and holds a list of "
    "license keys, where the field name is the feature "
    "name.\",\"items\":{\"type\":\"string\",\"description\":\"License key (example: "
    "'46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73')\"},\"minItems\":1}},\"title\":\"Software License Keys\"}"
    ,
    /* example: */
    "{\"MTA resolution\":[\"468E020A - 39A922E4 - B681A184 - 673E3D72\"],\"Full "
    "Waveform Analysis Topography with GPU support\":[\"8AB44126 - 23B92250 -"
    " 16E2689F - 34EF7E7B\"],\"Full Waveform Analysis Topography\":[\"0FD5FF07 "
    "- 011A1255 - 9F76CACA - 8D2ED557\"],\"Georeferencing\":[\"46AE032A - "
    "39882AC4 - 9EC0A184 - 6F163D73\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Parameters for MTA processing\",\"proper"
    "ties\":{\"zone_count\":{\"type\":\"integer\",\"description\":\"Maximum number of"
    " MTA zones.\",\"maximum\":255,\"minimum\":0},\"modulation_depth\":{\"type\":\"nu"
    "mber\",\"description\":\"Depth of pulse position modulation in meter.\",\"mi"
    "nimum\":0},\"zone_width\":{\"type\":\"number\",\"description\":\"Width of a MTA "
    "zone in meter.\",\"minimum\":0}},\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"title\":\"MTA Settings\"}"
    ,
    /* example: */
    "{\"zone_count\":23,\"modulation_depth\":9.368514,\"zone_width\":149.896225}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"delta\":{\"type\":\"number\",\"description\":\"Delta between "
    "table entries [m], first entry is at range = 0 "
    "m\"},\"content\":{\"type\":\"array\",\"description\":\"Correction value [m] to "
    "be added to the raw range\",\"items\":{\"type\":\"number\"},\"maxItems\":2000,\""
    "minItems\":1}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"typ"
    "e\":\"object\",\"description\":\"Lookup table for range correction based on "
    "raw range\",\"required\":[\"delta\",\"content\"],\"title\":\"Near Range "
    "Correction Table\"}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"range_sigma\":{\"type\":\"array\",\"description\":\"Sigma "
    "range [m]\",\"items\":{\"type\":\"number\"}},\"amplitude_sigma\":{\"type\":\"array"
    "\",\"description\":\"Sigma amplitude [dB]\",\"items\":{\"type\":\"number\"}},\"amp"
    "litude\":{\"type\":\"array\",\"description\":\"Amplitude [dB]\",\"items\":{\"type\""
    ":\"number\"}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type"
    "\":\"object\",\"description\":\"Standard deviation for range and amplitude "
    "as a function of amplitude\",\"required\":[\"amplitude\",\"range_sigma\",\"amp"
    "litude_sigma\"],\"title\":\"Noise Estimates\"}"
    ,
    /* example: */
    "{\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,"
    "0.016,0.014],\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0."
    "54,0.482,0.432,0.39,0.354],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7."
    "0,8.0,9.0,10.0]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum"
    " range [m]\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "range "
    "[m]\"},\"amplitude_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "amplitude [dB]\",\"minimum\":0}},\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"type\":\"object\",\"description\":\"Notch filter parameters for"
    " window glass echoes\",\"required\":[\"range_minimum\",\"range_maximum\",\"amp"
    "litude_maximum\"],\"title\":\"Notch Filter\"}"
    ,
    /* example: */
    "{\"range_maximum\":0.2,\"range_minimum\":-0.5,\"amplitude_maximum\":18.0}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"pixel_size\":{\"type\":\"array\",\"description\":\"Size of "
    "pixels.\",\"items\":{\"type\":\"number\",\"description\":\"Length of pixel edge "
    "[m].\",\"minimum\":0},\"maxItems\":2,\"minItems\":2}},\"properties\":{\"size\":{\""
    "$ref\":\"#/definitions/pixel_size\",\"description\":\"Size of pixels in file"
    " coordinate system.\"},\"size_llcs\":{\"$ref\":\"#/definitions/pixel_size\",\""
    "description\":\"Size of pixels in a locally levelled cartesian "
    "coordinate system (xy). This is only used for pixels based on a map pr"
    "ojection.\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type"
    "\":\"object\",\"description\":\"Details about the pixels contained in the "
    "file\",\"required\":[\"size\"],\"title\":\"Pixel Information\"}"
    ,
    /* example: */
    "{\"size\":[0.5971642834779395,0.5971642834779395],\"size_llcs\":[0.5156575"
    "252891171,0.5130835356683303]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"file_reference\":{\"type\":\"object\",\"description\":\"Refer"
    "ence to a plane patch "
    "file\",\"properties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane "
    "patch file's Universally Unique Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the plane "
    "patch file relative to the match file\"}},\"required\":[\"file_uuid\",\"file"
    "_path\"]}},\"properties\":{\"plane_patch_file_two\":{\"$ref\":\"#/definitions/"
    "file_reference\",\"description\":\"Reference to the plane patch file two\"}"
    ",\"plane_patch_file_one\":{\"$ref\":\"#/definitions/file_reference\",\"descri"
    "ption\":\"Reference to the plane patch file one\"}},\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Details "
    "about the plane patch matching process\",\"required\":[\"plane_patch_file_"
    "one\",\"plane_patch_file_two\"],\"title\":\"Plane Patch Matching\"}"
    ,
    /* example: */
    "{\"plane_patch_file_two\":{\"file_uuid\":\"fa47d509-a64e-49ce-8b14-ff3130fb"
    "efa9\",\"file_path\":\"project.ptch\"},\"plane_patch_file_one\":{\"file_uuid\":"
    "\"810f5d57-eccf-49ed-b07a-0cdd109b4213\",\"file_path\":\"Record009_Line001/"
    "191025_121410_Scanner_1.ptch\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Statistics about plane patches found "
    "by plane patch extractor\",\"properties\":{\"total_area\":{\"type\":\"number\","
    "\"description\":\"sum of all plane patch areas [m\\u00b2]\"},\"total_horizon"
    "tal_area\":{\"type\":\"number\",\"description\":\"sum of all plane patch areas"
    " projected to horizontal plane [m\\u00b2]\"}},\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"title\":\"Plane Patch Statistics\"}"
    ,
    /* example: */
    "{\"total_area\":14007.965,\"total_horizontal_area\":13954.601}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"method-2\":{\"type\":\"object\",\"description\":\"Classificat"
    "ion method 2\",\"properties\":{\"sloping_plane_classes_minimum_angle\":{\"ty"
    "pe\":\"number\",\"description\":\"minimum inclination angle of sloping plane"
    " patches [deg]\",\"maximum\":360.0,\"minimum\":-360.0},\"plane_classificatio"
    "n_method\":{\"type\":\"integer\",\"description\":\"method ID (=2)\",\"maximum\":2"
    ",\"minimum\":2},\"sloping_plane_classes_maximum_angle\":{\"type\":\"number\",\""
    "description\":\"maximum inclination angle of sloping plane patches [deg]"
    "\",\"maximum\":360.0,\"minimum\":-360.0}},\"required\":[\"plane_classification"
    "_method\",\"sloping_plane_classes_minimum_angle\",\"sloping_plane_classes_"
    "maximum_angle\"]},\"method-1\":{\"type\":\"object\",\"description\":\"Classifica"
    "tion method 1\",\"properties\":{\"plane_classification_method\":{\"type\":\"in"
    "teger\",\"description\":\"method ID (=1)\",\"maximum\":1,\"minimum\":1},\"maximu"
    "m_inclination_angle_horizontal\":{\"type\":\"number\",\"description\":\"maximu"
    "m inclination angle of horizontal plane patches [deg]\",\"maximum\":360.0"
    ",\"minimum\":-360.0}},\"required\":[\"plane_classification_method\",\"maximum"
    "_inclination_angle_horizontal\"]}},\"properties\":{\"classes\":{\"type\":\"obj"
    "ect\",\"description\":\"Class definition table\",\"patternProperties\":{\"^[0-"
    "9]+$\":{\"type\":\"string\",\"description\":\"one field per class, field name "
    "is class number, field value is class name\"}},\"additionalProperties\":f"
    "alse},\"settings\":{\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/definitions/meth"
    "od-1\"},{\"$ref\":\"#/definitions/method-2\"}],\"description\":\"Classificatio"
    "n settings, details see documentation of rdbplanes\"}},\"$schema\":\"http:"
    "//json-schema.org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Set"
    "tings and classes for plane slope "
    "classification\",\"required\":[\"settings\",\"classes\"],\"title\":\"Plane Slope"
    " Class Info\"}"
    ,
    /* example: */
    "{\"classes\":{\"13\":\"sloping, pointing down and west\",\"5\":\"sloping, "
    "pointing up and west\",\"6\":\"vertical, pointing east\",\"4\":\"sloping, "
    "pointing up and north\",\"10\":\"sloping, pointing down and "
    "east\",\"11\":\"sloping, pointing down and south\",\"1\":\"horizontal, "
    "pointing up\",\"14\":\"horizontal, pointing down\",\"3\":\"sloping, pointing "
    "up and south\",\"8\":\"vertical, pointing north\",\"12\":\"sloping, pointing "
    "down and north\",\"7\":\"vertical, pointing south\",\"9\":\"vertical, pointing"
    " west\",\"2\":\"sloping, pointing up and east\"},\"settings\":{\"sloping_plane"
    "_classes_minimum_angle\":10.0,\"plane_classification_method\":2,\"sloping_"
    "plane_classes_maximum_angle\":70.0}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"additionalProperties\":false,\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"type\":\"object\",\"description\":\"Grouping and sorting of "
    "point attributes for visualization purposes\",\"patternProperties\":{\"^.*"
    "$\":{\"type\":\"array\",\"description\":\"Each field of the object represents "
    "a point attribute group and holds a list of point attributes, where "
    "the field name is the group "
    "name.\",\"items\":{\"type\":\"string\",\"description\":\"Point attribute full "
    "name or name pattern (perl regular expression "
    "syntax)\"},\"minItems\":1}},\"title\":\"Point Attribute Groups\"}"
    ,
    /* example: */
    "{\"Other Attributes\":[\"riegl.selected\",\"riegl.visible\"],\"Coordinates/Ve"
    "ctors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"riegl.phi\"],\"Time\":[\""
    "riegl.timestamp\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Primary"
    " "
    "Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.deviation\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about point cloud files\",\"prop"
    "erties\":{\"comments\":{\"type\":\"string\",\"description\":\"Comments\"},\"field_"
    "of_application\":{\"type\":\"string\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\""
    "MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"description\":\"Field of "
    "application\"},\"project\":{\"type\":\"string\",\"description\":\"Project name\"}"
    "},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Point "
    "Cloud Information\"}"
    ,
    /* example: */
    "{\"comments\":\"Line 3\",\"field_of_application\":\"ALS\",\"project\":\"Campaign "
    "4\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"position\":{\"type\":\"object\",\"description\":\"Position "
    "coordinates and position accuracy values as measured by GNSS in the "
    "specified Coordinate Reference System (CRS)\",\"properties\":{\"coordinate"
    "_1\":{\"type\":\"number\",\"description\":\"Coordinate 1 as defined by axis 1 "
    "of the specified CRS (e.g., X, "
    "Latitude)\"},\"crs\":{\"type\":\"object\",\"description\":\"Global Coordinate "
    "Reference System\",\"properties\":{\"wkt\":{\"type\":\"string\",\"description\":\""
    "\\\"Well-Known Text\\\" string, OGC WKT dialect (see http://www.opengeospa"
    "tial.org/standards/wkt-crs)\"},\"epsg\":{\"type\":\"integer\",\"description\":\""
    "EPSG code\",\"minimum\":0}},\"required\":[\"epsg\"]},\"coordinate_2\":{\"type\":\""
    "number\",\"description\":\"Coordinate 2 as defined by axis 2 of the "
    "specified CRS (e.g., Y, "
    "Longitude)\"},\"coordinate_3\":{\"type\":\"number\",\"description\":\"Coordinate"
    " 3 as defined by axis 3 of the specified CRS (e.g., Z, Altitude)\"},\"ve"
    "rtical_accuracy\":{\"type\":\"number\",\"description\":\"Vertical accuracy [m]"
    "\",\"exclusiveMinimum\":true,\"minimum\":0},\"horizontal_accuracy\":{\"type\":\""
    "number\",\"description\":\"Horizontal accuracy [m]\",\"exclusiveMinimum\":tru"
    "e,\"minimum\":0}},\"required\":[\"coordinate_1\",\"coordinate_2\",\"coordinate_"
    "3\",\"horizontal_accuracy\",\"vertical_accuracy\",\"crs\"]},\"barometric_heigh"
    "t_amsl\":{\"type\":\"number\",\"description\":\"Altitude determined based on "
    "the atmospheric pressure according to the standard atmosphere laws "
    "[m].\"},\"orientation\":{\"type\":\"object\",\"description\":\"Orientation "
    "values and orientation accuracies, measured with IMU or inclination "
    "sensors.\",\"properties\":{\"pitch\":{\"type\":\"number\",\"description\":\"Pitch "
    "angle about scanner Y-axis [deg]\",\"maximum\":360,\"minimum\":-360},\"pitch"
    "_accuracy\":{\"type\":\"number\",\"description\":\"Pitch angle accuracy [deg]\""
    ",\"exclusiveMinimum\":true,\"minimum\":0},\"yaw_accuracy\":{\"type\":\"number\","
    "\"description\":\"Yaw angle accuracy [deg]\",\"exclusiveMinimum\":true,\"mini"
    "mum\":0},\"roll_accuracy\":{\"type\":\"number\",\"description\":\"Roll angle "
    "accuracy [deg]\",\"exclusiveMinimum\":true,\"minimum\":0},\"roll\":{\"type\":\"n"
    "umber\",\"description\":\"Roll angle about scanner X-axis [deg]\",\"maximum\""
    ":360,\"minimum\":-360},\"yaw\":{\"type\":\"number\",\"description\":\"Yaw angle "
    "about scanner Z-axis [deg]\",\"maximum\":360,\"minimum\":-360}},\"required\":"
    "[\"roll\",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitch_accuracy\",\"yaw_accuracy\"]"
    "}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\""
    ",\"description\":\"Estimated position and orientation information as "
    "measured by GNSS, IMU or inclination "
    "sensors\",\"required\":[\"orientation\"],\"title\":\"Pose Estimation\"}"
    ,
    /* example: */
    "{\"position\":{\"coordinate_1\":48.655799473,\"crs\":{\"wkt\":\"GEOGCS[\\\"WGS84 "
    "/ Geographic\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.2572"
    "23563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIM"
    "EM[\\\"Greenwich\\\",0.0000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT"
    "[\\\"Degree\\\",0.01745329251994329547,AUTHORITY[\\\"EPSG\\\",\\\"9102\\\"]],AXIS["
    "\\\"Latitude\\\",NORTH],AXIS[\\\"Longitude\\\",EAST],AUTHORITY[\\\"EPSG\\\",\\\"4979"
    "\\\"]]\",\"epsg\":4979},\"coordinate_2\":15.645033406,\"coordinate_3\":362.7124"
    "938964844,\"vertical_accuracy\":1.3314999341964722,\"horizontal_accuracy\""
    ":0.810699999332428},\"barometric_height_amsl\":386.7457796227932,\"orient"
    "ation\":{\"pitch\":1.509153024827064,\"pitch_accuracy\":0.00943378393687574"
    "5,\"yaw_accuracy\":1.0094337839368757,\"roll_accuracy\":0.0094337839368757"
    "45,\"roll\":3.14743073066123,\"yaw\":101.87293630292045}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"vector\":{\"type\":\"array\",\"items\":{\"type\":\"number\",\"des"
    "cription\":\"Index 0=X, 1=Y, 2=Z component\"},\"minItems\":3,\"maxItems\":3}}"
    ",\"properties\":{\"gyroscope\":{\"type\":\"object\",\"description\":\"Gyroscope d"
    "etails\",\"properties\":{\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"descrip"
    "tion\":\"Sensitive Y axis of sensor at frame angle = "
    "0\"},\"unit\":{\"type\":\"number\",\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in rad/s\",\"exclusiveMinimum\":true,\"minimum\":"
    "0},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor "
    "origin in SOCS [m] at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"},\"x_axis\":{\"$ref\":\"#/definiti"
    "ons/vector\",\"description\":\"Sensitive X axis of sensor at frame angle ="
    " 0\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive "
    "Z axis of sensor at frame angle = 0\"},\"relative_nonlinearity\":{\"$ref\":"
    "\"#/definitions/vector\",\"description\":\"Relative nonlinearity, dimension"
    "less\"}},\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin"
    "\",\"relative_nonlinearity\"]},\"accelerometer\":{\"type\":\"object\",\"descript"
    "ion\":\"Accelerometer details\",\"properties\":{\"y_axis\":{\"$ref\":\"#/definit"
    "ions/vector\",\"description\":\"Sensitive Y axis of sensor at frame angle "
    "= 0\"},\"unit\":{\"type\":\"number\",\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in 9.81 m/s\\u00b2\",\"exclusiveMinimum\":true,\""
    "minimum\":0},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sen"
    "sor origin in SOCS [m] at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"},\"x_axis\":{\"$ref\":\"#/definiti"
    "ons/vector\",\"description\":\"Sensitive X axis of sensor at frame angle ="
    " 0\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive "
    "Z axis of sensor at frame angle = 0\"},\"relative_nonlinearity\":{\"$ref\":"
    "\"#/definitions/vector\",\"description\":\"Relative nonlinearity, dimension"
    "less\"}},\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin"
    "\",\"relative_nonlinearity\"]},\"magnetic_field_sensor\":{\"type\":\"object\",\""
    "description\":\"Magnetic Field Sensor details\",\"properties\":{\"y_axis\":{\""
    "$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y axis of sensor"
    " at frame angle = 0\"},\"unit\":{\"type\":\"number\",\"description\":\"Unit of "
    "raw data and calibration values, 1 LSB in nT\",\"exclusiveMinimum\":true,"
    "\"minimum\":0},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Va"
    "lue to be subtracted from raw measurement values\"},\"x_axis\":{\"$ref\":\"#"
    "/definitions/vector\",\"description\":\"Sensitive X axis of sensor at "
    "frame angle = 0\"},\"relative_nonlinearity\":{\"$ref\":\"#/definitions/vecto"
    "r\",\"description\":\"Relative nonlinearity, dimensionless\"},\"z_axis\":{\"$r"
    "ef\":\"#/definitions/vector\",\"description\":\"Sensitive Z axis of sensor "
    "at frame angle = "
    "0\"},\"fixed\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Distortion "
    "of magnetic field caused by non-rotating scanner part\"}},\"required\":[\""
    "unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"fixed\",\"relative_nonlineari"
    "ty\"]}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"obj"
    "ect\",\"description\":\"Details on position and orientation sensors\",\"requ"
    "ired\":[\"gyroscope\",\"accelerometer\",\"magnetic_field_sensor\"],\"title\":\"P"
    "ose Sensors\"}"
    ,
    /* example: */
    "{\"gyroscope\":{\"y_axis\":[-0.440765917301178,-0.7897399663925171,119.589"
    "4775390625],\"unit\":0.00014544410805683583,\"origin\":[0.0269000008702278"
    "14,-0.03999999910593033,-0.08950000256299973],\"offset\":[-50.9260978698"
    "7305,146.15643310546875,62.4327278137207],\"x_axis\":[-121.195556640625,"
    "0.8219714164733887,0.2313031703233719],\"z_axis\":[0.555869996547699,119"
    ".22135162353516,0.467585027217865],\"relative_nonlinearity\":[2.88817631"
    "1444113e-07,1.06274164579645e-07,-1.7186295080634935e-39]},\"accelerome"
    "ter\":{\"y_axis\":[-7.027288913726807,-44.12333679199219,14952.3701171875"
    "],\"unit\":6.666666740784422e-05,\"origin\":[0.026900000870227814,-0.03999"
    "999910593033,-0.08950000256299973],\"offset\":[-733.3636474609375,58.969"
    "032287597656,1060.2550048828125],\"x_axis\":[-15008.123046875,56.9563903"
    "80859375,-60.5175666809082],\"z_axis\":[1.639882206916809,15166.74414062"
    "5,-116.99742889404297],\"relative_nonlinearity\":[0.0,0.0,0.0]},\"magneti"
    "c_field_sensor\":{\"y_axis\":[0.00027888521435670555,-0.01142742484807968"
    "1,-5.204829722060822e-05],\"unit\":91.74311828613281,\"offset\":[-23812.05"
    "2734375,5606.57666015625,2493.28125],\"x_axis\":[-0.011162743903696537,-"
    "2.315962774446234e-05,0.00016818844596855342],\"relative_nonlinearity\":"
    "[0.0,0.0,0.0],\"z_axis\":[0.00041987866279669106,7.876977906562388e-05,0"
    ".011407104320824146],\"fixed\":[-1576.010498046875,1596.081787109375,0.0"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"num_mod_ampl\":{\"type\":\"integer\",\"description\":\"Number "
    "of different modulation amplitudes (2: binary modulation)\",\"maximum\":2"
    "55,\"minimum\":0},\"code_phase_mode\":{\"type\":\"integer\",\"description\":\"0: "
    "no synchronization, 1: toggle between 2 phases, 2: increment with phas"
    "e_increment\",\"maximum\":255,\"minimum\":0},\"phase_step\":{\"type\":\"integer\""
    ",\"description\":\"Step width in phase of modulation code from line to li"
    "ne\",\"maximum\":255,\"minimum\":0},\"length\":{\"type\":\"integer\",\"description"
    "\":\"Length of code\",\"maximum\":255,\"minimum\":0},\"pulse_interval\":{\"type\""
    ":\"array\",\"description\":\"Explicit table of the pulse position "
    "modulation used for MTA resolution. Table gives times between "
    "successive laser pulses in seconds.\",\"items\":{\"type\":\"number\",\"minimum"
    "\":0}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"obj"
    "ect\",\"description\":\"Laser pulse position modulation used for MTA resol"
    "ution\",\"required\":[\"length\",\"num_mod_ampl\",\"pulse_interval\"],\"title\":\""
    "Pulse Position Modulation\"}"
    ,
    /* example: */
    "{\"num_mod_ampl\":2,\"code_phase_mode\":2,\"phase_step\":5,\"length\":31,\"puls"
    "e_interval\":[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821"
    "875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-"
    "06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2."
    "821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.75937"
    "5e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06"
    ",2.821875e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-06]}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "value\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "value\"},\"average\":{\"type\":\"number\",\"description\":\"Average value\"}},\"$s"
    "chema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"desc"
    "ription\":\"Statistics about target distance wrt. SOCS origin\",\"required"
    "\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"title\":\"Range "
    "Statistics\"}"
    ,
    /* example: */
    "{\"std_dev\":24.349,\"maximum\":574.35,\"minimum\":0.919,\"average\":15.49738}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"fp\":{\"type\":\"object\",\"description\":\"Fingerprint value"
    "s\",\"properties\":{\"s\":{\"type\":\"array\",\"items\":{\"type\":\"array\",\"items\":{"
    "\"type\":\"number\"},\"minItems\":1,\"maxItems\":4096},\"minItems\":1,\"maxItems\""
    ":256},\"w\":{\"type\":\"array\",\"items\":{\"type\":\"array\",\"items\":{\"type\":\"num"
    "ber\"},\"minItems\":5,\"maxItems\":5},\"minItems\":1,\"maxItems\":256}},\"requir"
    "ed\":[\"s\",\"w\"]},\"fp_table_row\":{\"type\":\"array\",\"items\":{\"type\":\"number\""
    "},\"minItems\":1,\"maxItems\":2048},\"fp_table\":{\"type\":\"object\",\"desriptio"
    "n\":\"scanner internal data\",\"required\":[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"],\"prop"
    "erties\":{\"ny\":{\"type\":\"integer\",\"description\":\"number of y entries\",\"m"
    "ax\":2048,\"min\":1},\"ch\":{\"type\":\"integer\",\"description\":\"channel number"
    "\",\"max\":255,\"min\":0},\"tv\":{\"type\":\"array\",\"items\":{\"oneOf\":[{\"$ref\":\"#"
    "/definitions/fp_table_row\"},{\"type\":\"number\"}]},\"minItems\":1,\"maxItems"
    "\":2048},\"nx\":{\"type\":\"integer\",\"description\":\"number of x entries\",\"ma"
    "x\":2048,\"min\":1},\"tc\":{\"type\":\"integer\",\"description\":\"table data type"
    " code\",\"max\":255,\"min\":0}}}},\"properties\":{\"mw\":{\"type\":\"number\",\"desc"
    "ription\":\"Maximum weight\",\"maximum\":4095,\"minimum\":0,\"exclusiveMinimum"
    "\":true},\"ns\":{\"type\":\"integer\",\"description\":\"Number of samples\",\"maxi"
    "mum\":4095,\"minimum\":0},\"a\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\""
    "minItems\":1,\"maxItems\":256,\"description\":\"Amplitude "
    "[dB]\"},\"ex\":{\"type\":\"object\",\"description\":\"DEPRECATED, use "
    "'riegl.exponential_decomposition' "
    "instead\"},\"si\":{\"type\":\"number\",\"description\":\"Start index (hw_start)\""
    ",\"maximum\":255,\"minimum\":0},\"tbl\":{\"type\":\"array\",\"items\":{\"$ref\":\"#/d"
    "efinitions/fp_table\"},\"minItems\":1,\"description\":\"various internal "
    "data\"},\"sr\":{\"type\":\"number\",\"description\":\"Sample rate [Hz]\",\"exclusi"
    "veMinimum\":true,\"minimum\":0},\"nt\":{\"type\":\"integer\",\"description\":\"Num"
    "ber of traces\",\"maximum\":255,\"minimum\":0},\"t\":{\"type\":\"object\",\"additi"
    "onalProperties\":false,\"patternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/defin"
    "itions/fp\",\"description\":\"one field per channel, field name is channel"
    " index\"}}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\""
    ":\"object\",\"description\":\"Receiver Internals\",\"title\":\"Receiver "
    "Internals\"}"
    ,
    /* example: */
    "{\"mw\":31,\"ns\":400,\"a\":[-1.55],\"si\":48,\"tbl\":[{\"ny\":2,\"ch\":0,\"tv\":[[1,2"
    ",3,4,5],[1.1,2.2,3.3,4.4,5.5]],\"nx\":5,\"tc\":1}],\"sr\":7959997000.0,\"nt\":"
    "128,\"t\":{\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],[7"
    "8,86,126,134,31]]},\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,"
    "134,31],[78,86,126,134,31]]}}}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"delta\":{\"type\":\"number\",\"description\":\"Delta between "
    "table entries [m], first entry is at range = 0 "
    "m\"},\"content\":{\"type\":\"array\",\"description\":\"Correction value [dB] to "
    "be added to the amplitude\",\"items\":{\"type\":\"number\"},\"maxItems\":2000,\""
    "minItems\":1}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"typ"
    "e\":\"object\",\"description\":\"Lookup table for reflectance calculation "
    "based on amplitude and "
    "range\",\"required\":[\"delta\",\"content\"],\"title\":\"Reflectance Calculation"
    " Table\"}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"reflectance_correction_db\":{\"type\":\"array\",\"descriptio"
    "n\":\"Near range reflectance correction in dB as a function of range "
    "over angle\",\"items\":{\"type\":\"array\",\"description\":\"rows (each array "
    "corresponds to a "
    "range)\",\"items\":{\"type\":\"number\",\"description\":\"columns (each value "
    "corresponds to an "
    "angle)\"}}},\"line_angles_deg\":{\"type\":\"array\",\"description\":\"Angle [deg"
    "]\",\"items\":{\"type\":\"number\"}},\"ranges_m\":{\"type\":\"array\",\"description\""
    ":\"Range [m]\",\"items\":{\"type\":\"number\"}}},\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Range-dependent "
    "and scan-angle-dependent correction of reflectance reading\",\"required\""
    ":[\"ranges_m\",\"line_angles_deg\",\"reflectance_correction_db\"],\"title\":\"N"
    "ear-range reflectance correction\"}"
    ,
    /* example: */
    "{\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0."
    "01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0"
    ".3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],\"li"
    "ne_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],\"ranges_m\":[0"
    ".0,1.0,2.0,3.0]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"program\":{\"type\":\"object\",\"description\":\"Measurement "
    "program\",\"properties\":{\"laser_prr\":{\"type\":\"number\",\"description\":\"Las"
    "er Pulse Repetition Rate [Hz]\",\"exclusiveMinimum\":false,\"minimum\":0},\""
    "name\":{\"type\":\"string\",\"description\":\"Name of measurement "
    "program\"}},\"required\":[\"name\"]}},\"description\":\"Scan pattern descripti"
    "on\",\"properties\":{\"rectangular\":{\"type\":\"object\",\"description\":\"Rectan"
    "gular Field Of View Scan Pattern\",\"properties\":{\"theta_increment\":{\"ty"
    "pe\":\"number\",\"description\":\"Increment of theta angle in SOCS [deg]\",\"m"
    "aximum\":90.0,\"minimum\":0.0},\"theta_start\":{\"type\":\"number\",\"descriptio"
    "n\":\"Start theta angle in SOCS [deg]\",\"maximum\":180.0,\"minimum\":0.0},\"t"
    "heta_stop\":{\"type\":\"number\",\"description\":\"Stop theta angle in SOCS [d"
    "eg]\",\"maximum\":180.0,\"minimum\":0.0},\"phi_stop\":{\"type\":\"number\",\"descr"
    "iption\":\"Stop phi angle in SOCS [deg]\",\"maximum\":720.0,\"minimum\":0.0},"
    "\"phi_start\":{\"type\":\"number\",\"description\":\"Start phi angle in SOCS [d"
    "eg]\",\"maximum\":360.0,\"minimum\":0.0},\"program\":{\"$ref\":\"#/definitions/p"
    "rogram\"},\"phi_increment\":{\"type\":\"number\",\"description\":\"Increment of "
    "phi angle in SOCS [deg]\",\"maximum\":90.0,\"minimum\":0.0}},\"required\":[\"p"
    "hi_start\",\"phi_stop\",\"phi_increment\",\"theta_start\",\"theta_stop\",\"theta"
    "_increment\"]},\"line\":{\"type\":\"object\",\"description\":\"Line Scan "
    "Pattern\",\"properties\":{\"stop\":{\"type\":\"number\",\"description\":\"Stop "
    "angle in SOCS [deg]\",\"maximum\":720.0,\"minimum\":0.0},\"increment\":{\"type"
    "\":\"number\",\"description\":\"Increment of angle in SOCS [deg]\",\"maximum\":"
    "90.0,\"minimum\":0.0},\"program\":{\"$ref\":\"#/definitions/program\"},\"start\""
    ":{\"type\":\"number\",\"description\":\"Start angle in SOCS [deg]\",\"maximum\":"
    "360.0,\"minimum\":0.0}},\"required\":[\"start\",\"stop\",\"increment\"]},\"segmen"
    "ts\":{\"type\":\"object\",\"description\":\"Segmented Line Scan Pattern\",\"prop"
    "erties\":{\"list\":{\"type\":\"array\",\"items\":{\"type\":\"object\",\"description\""
    ":\"Line Scan "
    "Segment\",\"properties\":{\"stop\":{\"type\":\"number\",\"description\":\"Stop "
    "angle in SOCS [deg]\",\"maximum\":720.0,\"minimum\":0.0},\"increment\":{\"type"
    "\":\"number\",\"description\":\"Increment of angle in SOCS [deg]\",\"maximum\":"
    "90.0,\"minimum\":0.0},\"start\":{\"type\":\"number\",\"description\":\"Start "
    "angle in SOCS [deg]\",\"maximum\":360.0,\"minimum\":0.0}},\"required\":[\"star"
    "t\",\"stop\",\"increment\"]}},\"program\":{\"$ref\":\"#/definitions/program\"}},\""
    "required\":[\"list\"]}},\"$schema\":\"http://json-schema.org/draft-04/schema"
    "#\",\"title\":\"Scan Pattern\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"theta_increment\":0.04,\"theta_start\":30.0,\"theta_stop\""
    ":130.0,\"phi_stop\":270.0,\"phi_start\":45.0,\"program\":{\"laser_prr\":100000"
    ".0,\"name\":\"High Speed\"},\"phi_increment\":0.04}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about laser shot files\",\"prope"
    "rties\":{\"shot_file\":{\"type\":\"object\",\"properties\":{\"file_uuid\":{\"type\""
    ":\"string\",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Shot file "
    "extension, without the leading dot\"}},\"required\":[\"file_extension\"]}},"
    "\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Shot "
    "Information\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_uuid\":\"26a00815-67c0-4bff-8fe8-c577378fe663\",\"file"
    "_extension\":\"sodx\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"filters\":{\"type\":\"array\",\"description\":\"List of point "
    "filters\",\"items\":{\"type\":\"object\",\"description\":\"Point filter "
    "definition\",\"properties\":{\"filter\":{\"type\":\"string\",\"description\":\"The"
    " RDB filter string to apply (e.g. when reading points or index), "
    "details see documentation of function "
    "select()\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a "
    "tooltip)\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true')"
    " or ignore ('false') this "
    "filter\"},\"title\":{\"type\":\"string\",\"description\":\"A short filter title "
    "(e.g. for display in a selection list)\"}},\"required\":[\"activated\",\"tit"
    "le\",\"description\",\"filter\"]}},\"activated\":{\"type\":\"boolean\",\"descripti"
    "on\":\"Apply ('true') or ignore ('false') all filters\"}},\"$schema\":\"http"
    "://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Po"
    "int filters applied in addition to the application-defined "
    "filters\",\"required\":[\"activated\",\"filters\"],\"title\":\"Stored filters\"}"
    ,
    /* example: */
    "{\"filters\":[{\"filter\":\"riegl.mta_uncertain_point == "
    "0\",\"description\":\"Ignore points with uncertain MTA zone "
    "assignment\",\"activated\":false,\"title\":\"Ignore uncertain points from "
    "MTA resolution\"},{\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"description\":\"Ignore points with an echo signal amplitude below "
    "the dynamic trigger\",\"activated\":false,\"title\":\"Ignore points below "
    "dynamic trigger level\"},{\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are outside the outer AABB in "
    "BOCS\",\"activated\":false,\"title\":\"Ignore points outside outer "
    "AABB\"},{\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are inside the inner AABB in "
    "BOCS\",\"activated\":false,\"title\":\"Ignore points inside inner "
    "AABB\"}],\"activated\":true}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"author\":{\"type\":\"string\",\"description\":\"Name of the "
    "author that created the document\"},\"$class\":{\"type\":\"string\",\"enum\":[\""
    "Document\"],\"description\":\"Object class "
    "name\"},\"version\":{\"type\":\"string\",\"description\":\"Document format "
    "version\"},\"timestamp\":{\"type\":\"string\",\"description\":\"Date and time of"
    " creation (e.g. 2019-06-19T13:32:10+02:00)\"},\"system\":{\"type\":\"object\""
    ",\"description\":\"The actual system description, details see "
    "documentation of RIEGL System Description\"}},\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Details of "
    "major system components like lidar sensors, cameras and navigation dev"
    "ices\",\"required\":[\"$class\",\"version\",\"author\",\"timestamp\",\"system\"],\"t"
    "itle\":\"System Description\"}"
    ,
    /* example: */
    "{\"author\":\"RIEGL LMS GmbH, Austria\",\"$class\":\"Document\",\"version\":\"1.2"
    ".1\",\"timestamp\":\"2022-09-30T11:56:26+00:00\",\"system\":{\"details\":\"see "
    "documentation of RIEGL System Description\"}}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"conversion_table\":{\"type\":\"object\",\"properties\":{\"tem"
    "perature\":{\"type\":\"array\",\"description\":\"Temperature [\\u00b0C]\",\"items"
    "\":{\"type\":\"number\"}},\"value\":{\"type\":\"array\",\"description\":\"LSB [1]\",\""
    "items\":{\"type\":\"number\"}}},\"required\":[\"value\",\"temperature\"]}},\"prope"
    "rties\":{\"Si\":{\"$ref\":\"#/definitions/conversion_table\",\"description\":\"C"
    "onversion table for Si channel\"},\"InGaAs_Si_Difference\":{\"$ref\":\"#/def"
    "initions/conversion_table\",\"description\":\"Conversion table for InGaAs "
    "- Si difference\"},\"InGaAs\":{\"$ref\":\"#/definitions/conversion_table\",\"d"
    "escription\":\"Conversion table for InGaAs channel\"}},\"$schema\":\"http://"
    "json-schema.org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Conve"
    "rsion of background radiation raw values to temperatures in "
    "\\u00b0C\",\"title\":\"Temperature Calculation Table\"}"
    ,
    /* example: */
    "{\"Si\":{\"temperature\":[546.300048828125,548.8164051212026,551.314393850"
    "0972,554.0144257850053,556.604252334815,559.2124464488079,561.80227299"
    "86177,564.4104671126105,567.0002936624203],\"value\":[0.0,64.00097659230"
    "323,128.0019531846065,192.0029297769097,256.0039063692129,320.00488296"
    "151616,384.0058595538194,448.0068361461226,512.0078127384259]},\"InGaAs"
    "_Si_Difference\":{\"temperature\":[1749.977111117893,1749.977111117893,17"
    "49.977111117893,1749.977111117893,1749.977111117893,1749.977111117893,"
    "1744.7813348796044,1681.9971312601092,1622.3944822534868],\"value\":[100"
    "0.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400.0885036"
    "774805,1500.0427259132668,1600.1327555162209,1700.0869777520065,1800.0"
    "411999877924]},\"InGaAs\":{\"temperature\":[307.22196722535614,309.1153478"
    "247277,311.1188086915047,313.10025350480055,315.2137946389828,317.2172"
    "555057597,319.2207163725366,321.2021611858325,323.3157023200148],\"valu"
    "e\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,256.0039"
    "063692129,320.00488296151616,384.0058595538194,448.0068361461226,512.0"
    "078127384259]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"system\":{\"type\":\"string\",\"enum\":[\"unknown\",\"UTC\",\"GPS\""
    "],\"description\":\"Time system (time "
    "standard)\"},\"epoch\":{\"type\":\"string\",\"description\":\"Date and time of "
    "timestamp '0' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:00+01:00)"
    ".\"},\"source\":{\"type\":\"string\",\"enum\":[\"unknown\",\"RTC\",\"GNSS\"],\"descrip"
    "tion\":\"Timestamp source\"}},\"$schema\":\"http://json-schema.org/draft-04/"
    "schema#\",\"type\":\"object\",\"description\":\"Base of timestamps "
    "(epoch)\",\"required\":[\"epoch\",\"source\"],\"title\":\"Time Base\"}"
    ,
    /* example: */
    "{\"system\":\"UTC\",\"epoch\":\"2015-10-27T00:00:00+00:00\",\"source\":\"GNSS\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"company\":{\"type\":\"string\",\"description\":\"Company "
    "name\"},\"project\":{\"type\":\"string\",\"description\":\"Project "
    "name\"},\"settings\":{\"type\":\"string\",\"description\":\"Settings used to "
    "calculate the trajectory (descriptive "
    "text)\"},\"software\":{\"type\":\"string\",\"description\":\"Software that "
    "calculated the trajectory (this may be the same or different software "
    "than the one that created the "
    "file)\"},\"time_interval\":{\"type\":\"object\",\"description\":\"Time interval "
    "statistics\",\"properties\":{\"std_dev\":{\"type\":\"number\",\"description\":\"St"
    "andard deviation of intervals "
    "[s]\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum time interval "
    "[s]\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum time interval "
    "[s]\"},\"average\":{\"type\":\"number\",\"description\":\"Average time interval "
    "[s]\"}},\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"]},\"field_of"
    "_application\":{\"type\":\"string\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"ML"
    "S\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"description\":\"Field of "
    "application\"},\"device\":{\"type\":\"string\",\"description\":\"Navigation "
    "device, e.g. "
    "name/type/serial\"},\"location\":{\"type\":\"string\",\"description\":\"Project "
    "location, e.g. city/state/country\"},\"navigation_frame\":{\"type\":\"string"
    "\",\"enum\":[\"unknown\",\"NED\",\"ENU\"],\"description\":\"Navigation frame (NED:"
    " North-East-Down, ENU: East-North-Up)\"}},\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Details about "
    "position+orientation files\",\"required\":[\"time_interval\",\"navigation_fr"
    "ame\"],\"title\":\"Trajectory Information\"}"
    ,
    /* example: */
    "{\"company\":\"RIEGL LMS\",\"project\":\"Campaign "
    "3\",\"settings\":\"default\",\"software\":\"Navigation Software XYZ\",\"time_int"
    "erval\":{\"std_dev\":5.51e-07,\"maximum\":0.005004883,\"minimum\":0.00500032,"
    "\"average\":0.00500053},\"field_of_application\":\"MLS\",\"device\":\"IMU Model"
    " 12/1, Serial# 12345\",\"location\":\"Horn\",\"navigation_frame\":\"NED\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"ttip_version\":{\"type\":\"integer\",\"description\":\"followi"
    "ng main.sub.ss.sss\",\"minimum\":0},\"ext_signal\":{\"type\":\"integer\",\"descr"
    "iption\":\"0 .. use input signal, 1 .. use output signal of channel\",\"mi"
    "nimum\":0},\"ext_bitmask\":{\"type\":\"integer\",\"description\":\"defines which"
    " of the internal pulse generators are to be started\",\"minimum\":0},\"out"
    "put_usage\":{\"type\":\"integer\",\"description\":\"0 .. no output, 1 .. "
    "output derived from internal clock, 2 .. output derived from dmi, 3 .."
    " output derived from external signal, 4 .. output static low, 5 .. "
    "output static high\",\"minimum\":0},\"out_interval\":{\"type\":\"integer\",\"des"
    "cription\":\"output pulse interval [0.1 msec]\",\"minimum\":0},\"in_min_dura"
    "tion\":{\"type\":\"integer\",\"description\":\"input signals with smaller "
    "pulse durations are ignored [0.1 msec]\",\"minimum\":0},\"out_delay\":{\"typ"
    "e\":\"integer\",\"description\":\"output pulse initial delay after start "
    "[0.1 "
    "msec]\",\"minimum\":0},\"out_polarity\":{\"type\":\"integer\",\"description\":\"0 "
    ".. positive edge, 1 .. negative edge\",\"minimum\":0},\"num_channel\":{\"typ"
    "e\":\"integer\",\"description\":\"number of input/output channels\",\"minimum\""
    ":0},\"out_duration\":{\"type\":\"integer\",\"description\":\"output pulse "
    "duration [0.1 "
    "msec]\",\"minimum\":0},\"channel\":{\"type\":\"integer\",\"description\":\"ID of "
    "input/output "
    "channel\",\"minimum\":0},\"input_usage\":{\"type\":\"integer\",\"description\":\"0"
    " .. deactivated, 1 .. just detecting and timestamping\",\"minimum\":0},\"o"
    "ut_num_pulses\":{\"type\":\"integer\",\"description\":\"number of output "
    "pulses to be generated, 0 .. infinite\",\"minimum\":0},\"dmi_incr\":{\"type\""
    ":\"integer\",\"description\":\"dmi, increment in "
    "ticks\"},\"in_max_delay\":{\"type\":\"integer\",\"description\":\"maximum delay "
    "to output pulse before fake event is generated [0.1 msec], zero "
    "indicates that no fake events are generated\",\"minimum\":0},\"input_descr"
    "\":{\"type\":\"string\",\"description\":\"descriptive "
    "string\"},\"dmi_max_time\":{\"type\":\"integer\",\"description\":\"dmi, maximum "
    "time interval between trigger events [0.1 msec]\",\"minimum\":0},\"in_max_"
    "duration\":{\"type\":\"integer\",\"description\":\"stops measurement of pulse "
    "duration of input signal [0.1 msec]\",\"minimum\":0},\"output_descr\":{\"typ"
    "e\":\"string\",\"description\":\"descriptive "
    "string\"},\"dmi_dist_per_tick\":{\"type\":\"number\",\"description\":\"dmi, "
    "distance per tick, just informative "
    "[m]\"},\"dmi_min_time\":{\"type\":\"integer\",\"description\":\"dmi, minimum "
    "time interval between trigger events [0.1 msec]\",\"minimum\":0},\"ext_del"
    "ay\":{\"type\":\"integer\",\"description\":\"external trigger, time delay [0.1"
    " msec]\",\"minimum\":0},\"in_polarity\":{\"type\":\"integer\",\"description\":\"0 "
    ".. positive edge, 1 .. negative "
    "edge\",\"minimum\":0},\"ext_channel\":{\"type\":\"integer\",\"description\":\"ID "
    "of channel used as external trigger input, 32 indicates none\",\"minimum"
    "\":0},\"ext_subdivider\":{\"type\":\"integer\",\"description\":\"reduces the "
    "frequency, default 1\",\"minimum\":0}},\"$schema\":\"http://json-schema.org/"
    "draft-04/schema#\",\"type\":\"object\",\"description\":\"Trigger-Timestamping-"
    "Unit/IP configuration\",\"required\":[\"ttip_version\",\"num_channel\",\"ext_c"
    "hannel\",\"ext_signal\",\"ext_delay\",\"ext_subdivider\",\"ext_bitmask\",\"dmi_i"
    "ncr\",\"dmi_min_time\",\"dmi_max_time\",\"dmi_dist_per_tick\",\"channel\",\"outp"
    "ut_descr\",\"input_descr\",\"output_usage\",\"input_usage\",\"out_polarity\",\"o"
    "ut_duration\",\"out_interval\",\"out_delay\",\"out_num_pulses\",\"in_polarity\""
    ",\"in_min_duration\",\"in_max_duration\",\"in_max_delay\"],\"title\":\"TTIP "
    "Configuration\"}"
    ,
    /* example: */
    "{\"ttip_version\":1,\"ext_signal\":0,\"ext_bitmask\":0,\"output_usage\":1,\"out"
    "_interval\":10000,\"in_min_duration\":0,\"out_delay\":0,\"out_polarity\":0,\"n"
    "um_channel\":9,\"out_duration\":300,\"channel\":0,\"input_usage\":1,\"out_num_"
    "pulses\":1,\"dmi_incr\":0,\"in_max_delay\":9990,\"input_descr\":\"Port 1 - Exp"
    "osure\",\"dmi_max_time\":0,\"in_max_duration\":10000,\"output_descr\":\"Port 1"
    " - Trigger\",\"dmi_dist_per_tick\":0.0,\"dmi_min_time\":0,\"ext_delay\":0,\"in"
    "_polarity\":0,\"ext_channel\":32,\"ext_subdivider\":1}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about vertex file\",\"properties"
    "\":{\"vertex_file\":{\"type\":\"object\",\"properties\":{\"file_uuid\":{\"type\":\"s"
    "tring\",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Vertex file "
    "extension, without the leading dot\"}},\"required\":[\"file_extension\"]}},"
    "\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Vertex "
    "Information\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_uuid\":\"51534d95-d71f-4f36-ae1a-3e63a21fd1c7\",\"fi"
    "le_extension\":\"vtx\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"voxel_size_cubic\":{\"$ref\":\"#/definitions/edge_length\""
    ",\"type\":\"number\"},\"voxel_origin_enum\":{\"default\":\"corner\",\"enum\":[\"cen"
    "ter\",\"corner\"],\"description\":\"Defines whether the voxel's center or a "
    "corner is placed on CRS origin <tt>(0/0/0)</tt>.\"},\"voxel_size\":{\"type"
    "\":\"array\",\"items\":{\"$ref\":\"#/definitions/edge_length\"},\"description\":\""
    "Size of voxels.\",\"maxItems\":3,\"minItems\":3},\"voxel_origin_point\":{\"typ"
    "e\":\"array\",\"description\":\"Origin point for all voxel indices in voxel "
    "CRS.\",\"items\":{\"type\":\"number\"},\"maxItems\":3,\"minItems\":3},\"shape_thre"
    "sholds\":{\"type\":\"object\",\"description\":\"Thresholds used to compute the"
    " voxel's shape_id "
    "value.\",\"properties\":{\"line\":{\"type\":\"number\",\"description\":\"If the "
    "biggest eigenvalue is bigger than the median eigenvalue * "
    "line_threshold, the voxel is considered a line.\",\"exclusiveMinimum\":tr"
    "ue,\"minimum\":1},\"plane\":{\"exclusiveMinimum\":true,\"type\":\"number\",\"excl"
    "usiveMaximum\":true,\"description\":\"If the smallest eigenvalue is "
    "smaller than the median eigenvalue * plane_threshold, the voxel is "
    "considered a plane.\",\"maximum\":1,\"minimum\":0}},\"required\":[\"plane\",\"li"
    "ne\"]},\"edge_length\":{\"type\":\"number\",\"description\":\"Length of voxel "
    "edge [m].\",\"exclusiveMinimum\":true,\"minimum\":0},\"voxel_type\":{\"default"
    "\":\"centroid\",\"enum\":[\"center\",\"centroid\",\"index\"],\"description\":\"Wheth"
    "er a point in a voxel represents its center or its centroid. If type "
    "is <tt>index</tt> there is no point but only an integer voxel index.\"}"
    "},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\","
    "\"oneOf\":[{\"additionalProperties\":false,\"properties\":{\"shape_thresholds"
    "\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"voxel_type\":{\"$ref\":\"#/de"
    "finitions/voxel_type\"},\"size\":{\"oneOf\":[{\"$ref\":\"#/definitions/voxel_s"
    "ize\"},{\"$ref\":\"#/definitions/voxel_size_cubic\"}],\"description\":\"Size "
    "of voxels in file coordinate system.\"},\"voxel_origin\":{\"$ref\":\"#/defin"
    "itions/voxel_origin_enum\"}},\"required\":[\"size\",\"voxel_origin\",\"voxel_t"
    "ype\"]},{\"additionalProperties\":false,\"properties\":{\"size_llcs\":{\"$ref\""
    ":\"#/definitions/voxel_size\",\"description\":\"Size of voxels in a locally"
    " levelled cartesian coordinate system (xyz). This is only used for "
    "voxels based on a map projection.\"},\"reference_point\":{\"type\":\"array\","
    "\"items\":{\"type\":\"number\",\"maximum\":180,\"minimum\":-180},\"description\":\""
    "Point in WGS84 geodetic decimal degree (EPSG:4326) that was used to "
    "compute the projection distortion parameters. The coefficient order is"
    " latitude, longitude. Only voxels with corresponding geo_tag, "
    "voxel_size and reference_point can be reliably processed together. "
    "This entry is available for voxel files in projected CRS only.\",\"maxIt"
    "ems\":2,\"minItems\":2},\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"},"
    "\"shape_thresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"voxel_or"
    "igin\":{\"oneOf\":[{\"$ref\":\"#/definitions/voxel_origin_enum\"},{\"$ref\":\"#/"
    "definitions/voxel_origin_point\",\"description\":\"The base point of the "
    "voxel grid. Used together with <tt>voxel_size</tt> and "
    "<tt>voxel_index</tt> to compute actual point coordinates.\"}]},\"size\":{"
    "\"$ref\":\"#/definitions/voxel_size\",\"description\":\"Size of voxels in "
    "file coordinate system.\"}},\"required\":[\"reference_point\",\"size_llcs\",\""
    "size\",\"voxel_origin\",\"voxel_type\"]}],\"description\":\"Details about the "
    "voxels contained in the file\",\"title\":\"Voxel Information\"}"
    ,
    /* example: */
    "{\"size_llcs\":[0.5156575252891171,0.5130835356683303,0.5143705304787237"
    "],\"reference_point\":[48,16],\"voxel_type\":\"centroid\",\"shape_thresholds\""
    ":{\"line\":6,\"plane\":0.16},\"voxel_origin\":\"corner\",\"size\":[0.59716428347"
    "79395,0.5971642834779395,0.5143705304787237]}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"trim\":{\"type\":\"number\",\"default\":0,\"description\":\"Perc"
    "entage for robust averaging.\",\"maximum\":0.5,\"minimum\":0},\"num_shots\":{"
    "\"type\":\"integer\",\"description\":\"Number of consecutive shots to be used"
    " for averaging.\",\"minimum\":1},\"mta_zone\":{\"type\":\"integer\",\"descriptio"
    "n\":\"Fixed MTA zone for averaging.\",\"minimum\":1}},\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Settings"
    " for waveform "
    "averaging\",\"required\":[\"num_shots\",\"mta_zone\"],\"title\":\"Waveform "
    "Averaging Settings\"}"
    ,
    /* example: */
    "{\"trim\":0.05,\"num_shots\":7,\"mta_zone\":1}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"sample_block_file\":{\"type\":\"object\",\"properties\":{\"fil"
    "e_uuid\":{\"type\":\"string\",\"description\":\"File's Universally Unique "
    "Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample block "
    "file extension, without the leading dot\"}},\"required\":[\"file_extension"
    "\"]},\"range_offset_m\":{\"type\":\"number\",\"description\":\"Calibrated device"
    " specific range offset for waveform analysis by system response "
    "fitting in meters.\"},\"sample_data_files\":{\"type\":\"array\",\"items\":{\"typ"
    "e\":\"object\",\"properties\":{\"sample_bits\":{\"maximum\":32,\"type\":\"integer\""
    ",\"exclusiveMaximum\":false,\"description\":\"Bitwidth of samples (e.g. 10 "
    "bit, 12 bit)\",\"exclusiveMinimum\":false,\"minimum\":0},\"delta_st\":{\"type\""
    ":\"number\",\"description\":\"reserved\"},\"channel_name\":{\"type\":\"string\",\"d"
    "escription\":\"Sample block channel "
    "name\"},\"laser_wavelength\":{\"type\":\"number\",\"description\":\"Laser "
    "wavelength in meters (0 = unknown)\",\"exclusiveMinimum\":false,\"minimum\""
    ":0},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"},\"channel\":{\"maximum\":255,\"type\":\"intege"
    "r\",\"exclusiveMaximum\":false,\"description\":\"Sample block channel number"
    " (255 = invalid)\",\"exclusiveMinimum\":false,\"minimum\":0},\"file_extensio"
    "n\":{\"type\":\"string\",\"description\":\"Sample data file extension, without"
    " the leading "
    "dot\"},\"sample_interval\":{\"type\":\"number\",\"description\":\"Sampling "
    "interval in seconds\",\"exclusiveMinimum\":false,\"minimum\":0}},\"required\""
    ":[\"channel\",\"channel_name\",\"sample_interval\",\"sample_bits\",\"laser_wave"
    "length\",\"delta_st\",\"file_extension\"]}},\"range_offset_waveform_samples_"
    "m\":{\"type\":\"number\",\"description\":\"Calibrated device specific range "
    "offset for waveform samples in meters.\"}},\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Details about "
    "waveform files\",\"required\":[\"sample_block_file\",\"sample_data_files\"],\""
    "title\":\"Waveform Information\"}"
    ,
    /* example: */
    "{\"sample_block_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe66"
    "0\",\"file_extension\":\"sbx\"},\"range_offset_m\":3.1415,\"sample_data_files\""
    ":[{\"sample_bits\":12,\"delta_st\":0,\"channel_name\":\"high_power\",\"laser_wa"
    "velength\":0,\"file_uuid\":\"da084413-e3e8-4655-a122-071de8490d8e\",\"channe"
    "l\":0,\"file_extension\":\"sp0\",\"sample_interval\":1.00503e-09},{\"sample_bi"
    "ts\":12,\"delta_st\":0,\"channel_name\":\"low_power\",\"laser_wavelength\":0,\"f"
    "ile_uuid\":\"93585b5e-5ea9-43a1-947b-e7ba3be642d2\",\"channel\":1,\"file_ext"
    "ension\":\"sp1\",\"sample_interval\":1.00503e-09},{\"sample_bits\":12,\"delta_"
    "st\":0,\"channel_name\":\"wwf\",\"laser_wavelength\":0,\"file_uuid\":\"9d2298c4-"
    "1036-464f-b5cb-1cf8e517f3a0\",\"channel\":5,\"file_extension\":\"sp5\",\"sampl"
    "e_interval\":1.00503e-09}],\"range_offset_waveform_samples_m \":7.283}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"items\":{\"type\":\"object\",\"properties\":{\"pass_ampl_less"
    "\":{\"type\":\"number\",\"description\":\"Threshold for amplitude less than "
    "[dB]\"},\"pass_rng_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "range less than "
    "[m]\"},\"logic_expression\":{\"type\":\"string\",\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart "
    "waveform output enabled\"},\"pass_ampl_greater\":{\"type\":\"number\",\"descri"
    "ption\":\"Threshold for amplitude greater than "
    "[dB]\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform output "
    "enabled\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold "
    "for deviation less than "
    "[1]\"},\"pass_dev_greater\":{\"type\":\"integer\",\"description\":\"Threshold "
    "for deviation greater than "
    "[1]\"},\"sbl_name\":{\"type\":\"string\",\"description\":\"Name of sample block,"
    " e.g.: wfm, "
    "wwf\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold for"
    " range greater than "
    "[m]\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask for"
    " channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, ...\"}},\"required\":[\"sbl_name\",\"enabled\",\"channel_idx_mask\"]},\"de"
    "scription\":\"Scanner settings for waveform output\",\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"title\":\"Waveform Settings\"}"
    ,
    /* example: */
    "[{\"pass_ampl_less\":5.0,\"pass_rng_less\":13.11,\"smart_enabled\":true,\"pas"
    "s_ampl_greater\":1.0,\"enabled\":true,\"sbl_name\":\"wfm\",\"pass_rng_greater\""
    ":9.27,\"channel_idx_mask\":11},{\"enabled\":false,\"sbl_name\":\"wwf\",\"channe"
    "l_idx_mask\":32}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"result\":{\"type\":\"object\",\"properties\":{\"range_sigma\":{"
    "\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[m]\"},\"angle\":"
    "{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[deg]\"},\"ampl"
    "itude_sigma\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\""
    "[dB]\"},\"range_mean\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descrip"
    "tion\":\"[m]\"},\"amplitude_mean\":{\"type\":\"array\",\"items\":{\"type\":\"number\""
    "},\"description\":\"[dB]\"},\"timestamp\":{\"type\":\"array\",\"items\":{\"type\":\"n"
    "umber\"},\"description\":\"[s]\"},\"amplitude_offset\":{\"type\":\"array\",\"items"
    "\":{\"type\":\"number\"},\"description\":\"[dB]\"}},\"required\":[\"angle\",\"range_"
    "mean\",\"range_sigma\",\"amplitude_mean\",\"amplitude_sigma\",\"amplitude_offs"
    "et\"]},\"settings\":{\"type\":\"object\",\"properties\":{\"amplitude\":{\"type\":\"o"
    "bject\",\"properties\":{\"additive_value\":{\"type\":\"number\"},\"sigma_factor\""
    ":{\"type\":\"number\"}},\"required\":[\"sigma_factor\",\"additive_value\"]},\"ran"
    "ge\":{\"type\":\"object\",\"properties\":{\"additive_value\":{\"type\":\"number\"},"
    "\"sigma_factor\":{\"type\":\"number\"}},\"required\":[\"sigma_factor\",\"additive"
    "_value\"]}},\"required\":[\"range\",\"amplitude\"]},\"filter\":{\"type\":\"object\""
    ",\"properties\":{\"range_min\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\""
    "description\":\"[m]\"},\"range_max\":{\"type\":\"array\",\"items\":{\"type\":\"numbe"
    "r\"},\"description\":\"[m]\"},\"angle\":{\"type\":\"array\",\"items\":{\"type\":\"numb"
    "er\"},\"description\":\"[deg]\"},\"amplitude_max\":{\"type\":\"array\",\"items\":{\""
    "type\":\"number\"},\"description\":\"[dB]\"}},\"required\":[\"angle\",\"range_min\""
    ",\"range_max\",\"amplitude_max\"]}},\"$schema\":\"http://json-schema.org/draf"
    "t-04/schema#\",\"type\":\"object\",\"description\":\"Window analysis data "
    "estimated from scandata and resulting filter "
    "parameters\",\"required\":[\"result\",\"filter\",\"settings\"],\"title\":\"Window "
    "Analysis\"}"
    ,
    /* example: */
    "{\"result\":{\"range_sigma\":[0.01869652,0.02151435,0.01747969,0.01918765,"
    "0.01945776,0.01934862,0.01955329,0.02225589,0.02229977,0.01899122,0.02"
    "009433],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15."
    "9],\"amplitude_sigma\":[0.4272844,0.4298479,0.4236816,0.4283583,0.436235"
    "3,0.4315141,0.4373984,0.4472798,0.4346001,0.4345487,0.4540681],\"range_"
    "mean\":[0.1105621,0.1079564,0.1087088,0.1067261,0.1054582,0.1090412,0.1"
    "02871,0.1019044,0.1051523,0.1058445,0.1031261],\"amplitude_mean\":[5.347"
    "396,5.263155,5.224655,5.179926,5.097782,5.116479,5.051756,4.983473,5.0"
    "07885,5.002441,4.982],\"timestamp\":[408.4441,411.4443],\"amplitude_offse"
    "t\":[1.9,1.9]},\"settings\":{\"amplitude\":{\"additive_value\":1.0,\"sigma_fac"
    "tor\":4},\"range\":{\"additive_value\":0.1,\"sigma_factor\":8}},\"filter\":{\"ra"
    "nge_min\":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0.221,-0.22"
    "3,-0.225,-0.227],\"range_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0.42"
    "9,0.43,0.431,0.431,0.432],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,"
    "15.6,15.7,15.8,15.9],\"amplitude_max\":[8.04,8.01,7.99,7.96,7.93,7.9,7.8"
    "8,7.85,7.83,7.8,7.78]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"range\":{\"type\":\"object\",\"description\":\"Range axis of "
    "correction "
    "table\",\"properties\":{\"entries\":{\"type\":\"integer\",\"description\":\"Number"
    " of range entries\",\"minimum\":1},\"maximum\":{\"type\":\"number\",\"descriptio"
    "n\":\"Maximum range in m\",\"maximum\":2.0,\"minimum\":-2.0},\"minimum\":{\"type"
    "\":\"number\",\"description\":\"Minimum range in m\",\"maximum\":2.0,\"minimum\":"
    "-2.0}},\"required\":[\"minimum\",\"maximum\",\"entries\"]},\"amplitude\":{\"type\""
    ":\"object\",\"description\":\"Amplitude axis of correction "
    "table\",\"properties\":{\"entries\":{\"type\":\"integer\",\"description\":\"Number"
    " of amplitude entries\",\"minimum\":1},\"maximum\":{\"type\":\"number\",\"descri"
    "ption\":\"Maximum amplitude in "
    "dB\",\"minimum\":0.0},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "amplitude in dB\",\"minimum\":0.0}},\"required\":[\"minimum\",\"maximum\",\"entr"
    "ies\"]},\"slices\":{\"type\":\"array\",\"items\":{\"type\":\"object\",\"description\""
    ":\"Window echo correction parameter "
    "slice\",\"properties\":{\"table\":{\"type\":\"array\",\"description\":\"Correction"
    " table (dimension defined by the 'amplitude' and 'range' "
    "objects)\",\"items\":{\"type\":\"array\",\"description\":\"Table row (= "
    "amplitude axis)\",\"items\":{\"type\":\"array\",\"description\":\"Table column "
    "(= range axis)\",\"items\":{\"type\":\"number\",\"description\":\"Table cell "
    "(item 0: amplitude in dB, 1: range in m, 2: flags)\"},\"maxItems\":3,\"min"
    "Items\":3},\"minItems\":1},\"minItems\":1},\"amplitude\":{\"type\":\"number\",\"de"
    "scription\":\"Window echo amplitude of slice in dB\"}},\"required\":[\"ampli"
    "tude\",\"table\"]}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\","
    "\"type\":\"object\",\"description\":\"Correction parameters for window glass "
    "echoes\",\"required\":[\"amplitude\",\"range\",\"slices\"],\"title\":\"Window Echo"
    " Correction\"}"
    ,
    /* example: */
    "{\"range\":{\"entries\":128,\"maximum\":1.5060822940732335,\"minimum\":-1.5060"
    "822940732335},\"amplitude\":{\"entries\":128,\"maximum\":20,\"minimum\":2},\"sl"
    "ices\":[{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\":1.5"
    "},{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\":2.0}]}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);

#endif // RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
